summaryrefslogtreecommitdiff
path: root/src/tr.c
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1994-07-12 13:21:49 +0000
committerJim Meyering <jim@meyering.net>1994-07-12 13:21:49 +0000
commite577b09b46b866f0463ecbd4c686ed15a6784358 (patch)
treed71f69a369f5de0dbf92d1d197c46cb72cc315a3 /src/tr.c
parent53cd09b3bc2052322cd4d7defe6853e5211d8e27 (diff)
downloadcoreutils-e577b09b46b866f0463ecbd4c686ed15a6784358.tar.xz
.
Diffstat (limited to 'src/tr.c')
-rw-r--r--src/tr.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/tr.c b/src/tr.c
index a41e59ce7..fe899c0fe 100644
--- a/src/tr.c
+++ b/src/tr.c
@@ -451,7 +451,7 @@ is_char_class_member (char_class, c)
/* Perform the first pass over each range-spec argument S,
converting all \c and \ddd escapes to their one-byte representations.
The conversion is done in-place, so S must point to writable
- storage. If an illegal quote sequence is found, an error message is
+ storage. If an invalid quote sequence is found, an error message is
printed and the function returns non-zero. Otherwise the length of
the resulting string is returned through LEN and the function returns 0.
The resulting array of characters may contain zero-bytes; however,
@@ -1431,7 +1431,7 @@ validate (s1, s2)
error (1, 0, "the [c*] repeat construct may not appear in string1");
}
/* FIXME: it isn't clear from the POSIX spec that this is illegal,
but in the spirit of the other restrictions put on translation
with character classes, this seems a logical interpretation. */
if (complement && s1->has_upper_or_lower)
@@ -1767,7 +1767,7 @@ main (argc, argv)
/* Change this test if it is legal to give tr no options and
no args at all. POSIX doesn't specifically say anything
- either way, but it looks like they implied it's illegal
+ either way, but it looks like they implied it's invalid
by omission. If you want to make tr do a slow imitation
of `cat' use `tr a a'. */
if (non_option_args > 2)
@@ -1431,7 +1431,7 @@ validate (s1, s2)
error (1, 0, "the [c*] repeat construct may not appear in string1");
}
- /* FIXME: it isn't clear from the POSIX spec that this is illegal,
+ /* FIXME: it isn't clear from the POSIX spec that this is invalid,
but in the spirit of the other restrictions put on translation
with character classes, this seems a logical interpretation. */